summaryrefslogtreecommitdiff
path: root/keystoneclient/v3/client.py
diff options
context:
space:
mode:
Diffstat (limited to 'keystoneclient/v3/client.py')
-rw-r--r--keystoneclient/v3/client.py12
1 files changed, 8 insertions, 4 deletions
diff --git a/keystoneclient/v3/client.py b/keystoneclient/v3/client.py
index 34bdfad..3d37e3c 100644
--- a/keystoneclient/v3/client.py
+++ b/keystoneclient/v3/client.py
@@ -21,6 +21,7 @@ from keystoneclient.auth.identity import v3 as v3_auth
from keystoneclient import exceptions
from keystoneclient import httpclient
from keystoneclient.i18n import _
+from keystoneclient.v3 import auth
from keystoneclient.v3.contrib import endpoint_filter
from keystoneclient.v3.contrib import endpoint_policy
from keystoneclient.v3.contrib import federation
@@ -65,11 +66,13 @@ class Client(httpclient.HTTPClient):
:param string project_domain_name: Project's domain name for project
scoping. (optional)
:param string tenant_name: Tenant name. (optional)
- The tenant_name keyword argument is deprecated,
- use project_name instead.
+ The tenant_name keyword argument is deprecated
+ as of the 1.7.0 release in favor of project_name
+ and may be removed in the 2.0.0 release.
:param string tenant_id: Tenant id. (optional)
- The tenant_id keyword argument is deprecated,
- use project_id instead.
+ The tenant_id keyword argument is deprecated as of
+ the 1.7.0 release in favor of project_id and may
+ be removed in the 2.0.0 release.
:param string auth_url: Identity service endpoint for authorization.
:param string region_name: Name of a region to select when choosing an
endpoint from the service catalog.
@@ -179,6 +182,7 @@ EndpointPolicyManager`
"""Initialize a new client for the Keystone v3 API."""
super(Client, self).__init__(**kwargs)
+ self.auth = auth.AuthManager(self._adapter)
self.credentials = credentials.CredentialManager(self._adapter)
self.ec2 = ec2.EC2Manager(self._adapter)
self.endpoint_filter = endpoint_filter.EndpointFilterManager(